==> org-lsst-sal-camera-2.6.2-sources.jar: org/lsst/sal/camera/telemetry/Chiller_ChillerTelemetry.java <==
package org.lsst.sal.camera.telemetry;

import org.lsst.sal.camera.CameraTelemetry;

public class Chiller_ChillerTelemetry extends CameraTelemetry {
  private final double chillerPumpLife;

  private final double chillerStatus;

  private final double chillerValveAct;

  private final double compressorLife;

  private final double controllerLife;

  private final double coolPercentage;

  private final double flowRate;

  private final double flowSetPoint;

  private final double fluidTemperature;

  private final double heatPercentage;

  private final double importedColdTemp;

  private final double pressureIn;

  private final double pressureOut;

  private final double pressureTank;

  private final double tankSetPoint;

  private final double tempCondenser;

  private final double tempDUTInput;

  private final double tempDynamicSetPt;

  private final double tempSetPoint;

  private final double tempStage2Evap;

  private final double tempTXVBulb;

  public Chiller_ChillerTelemetry(double chillerPumpLife, double chillerStatus,
      double chillerValveAct, double compressorLife, double controllerLife, double coolPercentage,
      double flowRate, double flowSetPoint, double fluidTemperature, double heatPercentage,
      double importedColdTemp, double pressureIn, double pressureOut, double pressureTank,
      double tankSetPoint, double tempCondenser, double tempDUTInput, double tempDynamicSetPt,
      double tempSetPoint, double tempStage2Evap, double tempTXVBulb) {
    this.chillerPumpLife = chillerPumpLife;
    this.chillerStatus = chillerStatus;
    this.chillerValveAct = chillerValveAct;
    this.compressorLife = compressorLife;
    this.controllerLife = controllerLife;
    this.coolPercentage = coolPercentage;
    this.flowRate = flowRate;
    this.flowSetPoint = flowSetPoint;
    this.fluidTemperature = fluidTemperature;
    this.heatPercentage = heatPercentage;
    this.importedColdTemp = importedColdTemp;
    this.pressureIn = pressureIn;
    this.pressureOut = pressureOut;
    this.pressureTank = pressureTank;
    this.tankSetPoint = tankSetPoint;
    this.tempCondenser = tempCondenser;
    this.tempDUTInput = tempDUTInput;
    this.tempDynamicSetPt = tempDynamicSetPt;
    this.tempSetPoint = tempSetPoint;
    this.tempStage2Evap = tempStage2Evap;
    this.tempTXVBulb = tempTXVBulb;
  }

  public double getChillerPumpLife() {
    return chillerPumpLife;
  }

  public double getChillerStatus() {
    return chillerStatus;
  }

  public double getChillerValveAct() {
    return chillerValveAct;
  }

  public double getCompressorLife() {
    return compressorLife;
  }

  public double getControllerLife() {
    return controllerLife;
  }

  public double getCoolPercentage() {
    return coolPercentage;
  }

  public double getFlowRate() {
    return flowRate;
  }

  public double getFlowSetPoint() {
    return flowSetPoint;
  }

  public double getFluidTemperature() {
    return fluidTemperature;
  }

  public double getHeatPercentage() {
    return heatPercentage;
  }

  public double getImportedColdTemp() {
    return importedColdTemp;
  }

  public double getPressureIn() {
    return pressureIn;
  }

  public double getPressureOut() {
    return pressureOut;
  }

  public double getPressureTank() {
    return pressureTank;
  }

  public double getTankSetPoint() {
    return tankSetPoint;
  }

  public double getTempCondenser() {
    return tempCondenser;
  }

  public double getTempDUTInput() {
    return tempDUTInput;
  }

  public double getTempDynamicSetPt() {
    return tempDynamicSetPt;
  }

  public double getTempSetPoint() {
    return tempSetPoint;
  }

  public double getTempStage2Evap() {
    return tempStage2Evap;
  }

  public double getTempTXVBulb() {
    return tempTXVBulb;
  }

  @Override
  public String toString() {
    return "Chiller_ChillerTelemetry{" + "chillerPumpLife=" + chillerPumpLife +
        ", chillerStatus=" + chillerStatus +", chillerValveAct=" + chillerValveAct +
        ", compressorLife=" + compressorLife +", controllerLife=" + controllerLife +
        ", coolPercentage=" + coolPercentage +", flowRate=" + flowRate +
        ", flowSetPoint=" + flowSetPoint +", fluidTemperature=" + fluidTemperature +
        ", heatPercentage=" + heatPercentage +", importedColdTemp=" + importedColdTemp +
        ", pressureIn=" + pressureIn +", pressureOut=" + pressureOut +
        ", pressureTank=" + pressureTank +", tankSetPoint=" + tankSetPoint +
        ", tempCondenser=" + tempCondenser +", tempDUTInput=" + tempDUTInput +
        ", tempDynamicSetPt=" + tempDynamicSetPt +", tempSetPoint=" + tempSetPoint +
        ", tempStage2Evap=" + tempStage2Evap +", tempTXVBulb=" + tempTXVBulb +"}";
  }

  public static Builder builder() {
    return new Builder();
  }

  public static class Builder {
    private double chillerPumpLife;

    private double chillerStatus;

    private double chillerValveAct;

    private double compressorLife;

    private double controllerLife;

    private double coolPercentage;

    private double flowRate;

    private double flowSetPoint;

    private double fluidTemperature;

    private double heatPercentage;

    private double importedColdTemp;

    private double pressureIn;

    private double pressureOut;

    private double pressureTank;

    private double tankSetPoint;

    private double tempCondenser;

    private double tempDUTInput;

    private double tempDynamicSetPt;

    private double tempSetPoint;

    private double tempStage2Evap;

    private double tempTXVBulb;

    private Builder() {
    }

    public Builder chillerPumpLife(double chillerPumpLife) {
      this.chillerPumpLife = chillerPumpLife;
      return this;
    }

    public Builder chillerStatus(double chillerStatus) {
      this.chillerStatus = chillerStatus;
      return this;
    }

    public Builder chillerValveAct(double chillerValveAct) {
      this.chillerValveAct = chillerValveAct;
      return this;
    }

    public Builder compressorLife(double compressorLife) {
      this.compressorLife = compressorLife;
      return this;
    }

    public Builder controllerLife(double controllerLife) {
      this.controllerLife = controllerLife;
      return this;
    }

    public Builder coolPercentage(double coolPercentage) {
      this.coolPercentage = coolPercentage;
      return this;
    }

    public Builder flowRate(double flowRate) {
      this.flowRate = flowRate;
      return this;
    }

    public Builder flowSetPoint(double flowSetPoint) {
      this.flowSetPoint = flowSetPoint;
      return this;
    }

    public Builder fluidTemperature(double fluidTemperature) {
      this.fluidTemperature = fluidTemperature;
      return this;
    }

    public Builder heatPercentage(double heatPercentage) {
      this.heatPercentage = heatPercentage;
      return this;
    }

    public Builder importedColdTemp(double importedColdTemp) {
      this.importedColdTemp = importedColdTemp;
      return this;
    }

    public Builder pressureIn(double pressureIn) {
      this.pressureIn = pressureIn;
      return this;
    }

    public Builder pressureOut(double pressureOut) {
      this.pressureOut = pressureOut;
      return this;
    }

    public Builder pressureTank(double pressureTank) {
      this.pressureTank = pressureTank;
      return this;
    }

    public Builder tankSetPoint(double tankSetPoint) {
      this.tankSetPoint = tankSetPoint;
      return this;
    }

    public Builder tempCondenser(double tempCondenser) {
      this.tempCondenser = tempCondenser;
      return this;
    }

    public Builder tempDUTInput(double tempDUTInput) {
      this.tempDUTInput = tempDUTInput;
      return this;
    }

    public Builder tempDynamicSetPt(double tempDynamicSetPt) {
      this.tempDynamicSetPt = tempDynamicSetPt;
      return this;
    }

    public Builder tempSetPoint(double tempSetPoint) {
      this.tempSetPoint = tempSetPoint;
      return this;
    }

    public Builder tempStage2Evap(double tempStage2Evap) {
      this.tempStage2Evap = tempStage2Evap;
      return this;
    }

    public Builder tempTXVBulb(double tempTXVBulb) {
      this.tempTXVBulb = tempTXVBulb;
      return this;
    }

    public Chiller_ChillerTelemetry build() {
      return new Chiller_ChillerTelemetry(chillerPumpLife, chillerStatus, chillerValveAct, compressorLife, controllerLife, coolPercentage, flowRate, flowSetPoint, fluidTemperature, heatPercentage, importedColdTemp, pressureIn, pressureOut, pressureTank, tankSetPoint, tempCondenser, tempDUTInput, tempDynamicSetPt, tempSetPoint, tempStage2Evap, tempTXVBulb);
    }
  }
}

==> org-lsst-sal-camera-2.6.4-sources.jar: org/lsst/sal/camera/telemetry/Chiller_ChillerTelemetry.java <==
package org.lsst.sal.camera.telemetry;

import org.lsst.sal.camera.CameraTelemetry;

public class Chiller_ChillerTelemetry extends CameraTelemetry {
  private final double chillerPumpLife;

  private final double chillerValveAct;

  private final double compressorLife;

  private final double controllerLife;

  private final double coolPercentage;

  private final double flowRate;

  private final double flowSetPoint;

  private final double fluidTemperature;

  private final double heatPercentage;

  private final double importedColdTemp;

  private final double pressureIn;

  private final double pressureOut;

  private final double pressureTank;

  private final double tankSetPoint;

  private final double tempCondenser;

  private final double tempDUTInput;

  private final double tempDynamicSetPt;

  private final double tempSetPoint;

  private final double tempStage2Evap;

  private final double tempTXVBulb;

  public Chiller_ChillerTelemetry(double chillerPumpLife, double chillerValveAct,
      double compressorLife, double controllerLife, double coolPercentage, double flowRate,
      double flowSetPoint, double fluidTemperature, double heatPercentage, double importedColdTemp,
      double pressureIn, double pressureOut, double pressureTank, double tankSetPoint,
      double tempCondenser, double tempDUTInput, double tempDynamicSetPt, double tempSetPoint,
      double tempStage2Evap, double tempTXVBulb) {
    this.chillerPumpLife = chillerPumpLife;
    this.chillerValveAct = chillerValveAct;
    this.compressorLife = compressorLife;
    this.controllerLife = controllerLife;
    this.coolPercentage = coolPercentage;
    this.flowRate = flowRate;
    this.flowSetPoint = flowSetPoint;
    this.fluidTemperature = fluidTemperature;
    this.heatPercentage = heatPercentage;
    this.importedColdTemp = importedColdTemp;
    this.pressureIn = pressureIn;
    this.pressureOut = pressureOut;
    this.pressureTank = pressureTank;
    this.tankSetPoint = tankSetPoint;
    this.tempCondenser = tempCondenser;
    this.tempDUTInput = tempDUTInput;
    this.tempDynamicSetPt = tempDynamicSetPt;
    this.tempSetPoint = tempSetPoint;
    this.tempStage2Evap = tempStage2Evap;
    this.tempTXVBulb = tempTXVBulb;
  }

  public double getChillerPumpLife() {
    return chillerPumpLife;
  }

  public double getChillerValveAct() {
    return chillerValveAct;
  }

  public double getCompressorLife() {
    return compressorLife;
  }

  public double getControllerLife() {
    return controllerLife;
  }

  public double getCoolPercentage() {
    return coolPercentage;
  }

  public double getFlowRate() {
    return flowRate;
  }

  public double getFlowSetPoint() {
    return flowSetPoint;
  }

  public double getFluidTemperature() {
    return fluidTemperature;
  }

  public double getHeatPercentage() {
    return heatPercentage;
  }

  public double getImportedColdTemp() {
    return importedColdTemp;
  }

  public double getPressureIn() {
    return pressureIn;
  }

  public double getPressureOut() {
    return pressureOut;
  }

  public double getPressureTank() {
    return pressureTank;
  }

  public double getTankSetPoint() {
    return tankSetPoint;
  }

  public double getTempCondenser() {
    return tempCondenser;
  }

  public double getTempDUTInput() {
    return tempDUTInput;
  }

  public double getTempDynamicSetPt() {
    return tempDynamicSetPt;
  }

  public double getTempSetPoint() {
    return tempSetPoint;
  }

  public double getTempStage2Evap() {
    return tempStage2Evap;
  }

  public double getTempTXVBulb() {
    return tempTXVBulb;
  }

  @Override
  public String toString() {
    return "Chiller_ChillerTelemetry{" + "chillerPumpLife=" + chillerPumpLife +
        ", chillerValveAct=" + chillerValveAct +", compressorLife=" + compressorLife +
        ", controllerLife=" + controllerLife +", coolPercentage=" + coolPercentage +
        ", flowRate=" + flowRate +", flowSetPoint=" + flowSetPoint +
        ", fluidTemperature=" + fluidTemperature +", heatPercentage=" + heatPercentage +
        ", importedColdTemp=" + importedColdTemp +", pressureIn=" + pressureIn +
        ", pressureOut=" + pressureOut +", pressureTank=" + pressureTank +
        ", tankSetPoint=" + tankSetPoint +", tempCondenser=" + tempCondenser +
        ", tempDUTInput=" + tempDUTInput +", tempDynamicSetPt=" + tempDynamicSetPt +
        ", tempSetPoint=" + tempSetPoint +", tempStage2Evap=" + tempStage2Evap +
        ", tempTXVBulb=" + tempTXVBulb +"}";
  }

  public static Builder builder() {
    return new Builder();
  }

  public static class Builder {
    private double chillerPumpLife;

    private double chillerValveAct;

    private double compressorLife;

    private double controllerLife;

    private double coolPercentage;

    private double flowRate;

    private double flowSetPoint;

    private double fluidTemperature;

    private double heatPercentage;

    private double importedColdTemp;

    private double pressureIn;

    private double pressureOut;

    private double pressureTank;

    private double tankSetPoint;

    private double tempCondenser;

    private double tempDUTInput;

    private double tempDynamicSetPt;

    private double tempSetPoint;

    private double tempStage2Evap;

    private double tempTXVBulb;

    private Builder() {
    }

    public Builder chillerPumpLife(double chillerPumpLife) {
      this.chillerPumpLife = chillerPumpLife;
      return this;
    }

    public Builder chillerValveAct(double chillerValveAct) {
      this.chillerValveAct = chillerValveAct;
      return this;
    }

    public Builder compressorLife(double compressorLife) {
      this.compressorLife = compressorLife;
      return this;
    }

    public Builder controllerLife(double controllerLife) {
      this.controllerLife = controllerLife;
      return this;
    }

    public Builder coolPercentage(double coolPercentage) {
      this.coolPercentage = coolPercentage;
      return this;
    }

    public Builder flowRate(double flowRate) {
      this.flowRate = flowRate;
      return this;
    }

    public Builder flowSetPoint(double flowSetPoint) {
      this.flowSetPoint = flowSetPoint;
      return this;
    }

    public Builder fluidTemperature(double fluidTemperature) {
      this.fluidTemperature = fluidTemperature;
      return this;
    }

    public Builder heatPercentage(double heatPercentage) {
      this.heatPercentage = heatPercentage;
      return this;
    }

    public Builder importedColdTemp(double importedColdTemp) {
      this.importedColdTemp = importedColdTemp;
      return this;
    }

    public Builder pressureIn(double pressureIn) {
      this.pressureIn = pressureIn;
      return this;
    }

    public Builder pressureOut(double pressureOut) {
      this.pressureOut = pressureOut;
      return this;
    }

    public Builder pressureTank(double pressureTank) {
      this.pressureTank = pressureTank;
      return this;
    }

    public Builder tankSetPoint(double tankSetPoint) {
      this.tankSetPoint = tankSetPoint;
      return this;
    }

    public Builder tempCondenser(double tempCondenser) {
      this.tempCondenser = tempCondenser;
      return this;
    }

    public Builder tempDUTInput(double tempDUTInput) {
      this.tempDUTInput = tempDUTInput;
      return this;
    }

    public Builder tempDynamicSetPt(double tempDynamicSetPt) {
      this.tempDynamicSetPt = tempDynamicSetPt;
      return this;
    }

    public Builder tempSetPoint(double tempSetPoint) {
      this.tempSetPoint = tempSetPoint;
      return this;
    }

    public Builder tempStage2Evap(double tempStage2Evap) {
      this.tempStage2Evap = tempStage2Evap;
      return this;
    }

    public Builder tempTXVBulb(double tempTXVBulb) {
      this.tempTXVBulb = tempTXVBulb;
      return this;
    }

    public Chiller_ChillerTelemetry build() {
      return new Chiller_ChillerTelemetry(chillerPumpLife, chillerValveAct, compressorLife, controllerLife, coolPercentage, flowRate, flowSetPoint, fluidTemperature, heatPercentage, importedColdTemp, pressureIn, pressureOut, pressureTank, tankSetPoint, tempCondenser, tempDUTInput, tempDynamicSetPt, tempSetPoint, tempStage2Evap, tempTXVBulb);
    }
  }
}
